summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorsunflowerskater <sunflowerskater@tutanota.com>2022-12-15 22:28:07 -0300
committerAntónio Fernandes <antoniof@gnome.org>2023-01-08 12:37:58 +0000
commitdcdeaf67e6f102adaa1b40f6532e13042d390873 (patch)
tree426ea68ddf0908a58b6d930df40597cf67722e26
parentf5ad89e52c88fb085d1c035a9e381edc8c69e96f (diff)
downloadnautilus-dcdeaf67e6f102adaa1b40f6532e13042d390873.tar.gz
general: Rename "application" to "app"
This is part of an initiative to use the "app" term instead: https://gitlab.gnome.org/Teams/Design/initiatives/-/issues/123
-rw-r--r--data/org.gnome.Nautilus.appdata.xml.in.in2
-rw-r--r--data/org.gnome.nautilus.gschema.xml4
-rw-r--r--src/gtk/nautilusgtkplacessidebar.c2
-rw-r--r--src/gtk/nautilusgtkplacesview.c2
-rw-r--r--src/nautilus-app-chooser.c6
-rw-r--r--src/nautilus-application.c2
-rw-r--r--src/nautilus-dbus-launcher.c4
-rw-r--r--src/nautilus-mime-actions.c14
-rw-r--r--src/nautilus-operations-ui-manager.c2
-rw-r--r--src/nautilus-program-choosing.c6
-rw-r--r--src/resources/gtk/help-overlay.ui2
-rw-r--r--src/resources/ui/nautilus-app-chooser.ui2
12 files changed, 24 insertions, 24 deletions
diff --git a/data/org.gnome.Nautilus.appdata.xml.in.in b/data/org.gnome.Nautilus.appdata.xml.in.in
index 7ed4c165c..93867c30a 100644
--- a/data/org.gnome.Nautilus.appdata.xml.in.in
+++ b/data/org.gnome.Nautilus.appdata.xml.in.in
@@ -12,7 +12,7 @@
<p>
Nautilus supports all the basic functions of a file manager and more.
It can search and manage your files and folders, both locally and on a network,
- read and write data to and from removable media, run scripts, and launch applications.
+ read and write data to and from removable media, run scripts, and launch apps.
It has three views: Icon Grid, Icon List, and Tree List.
Its functions can be extended with plugins and scripts.
</p>
diff --git a/data/org.gnome.nautilus.gschema.xml b/data/org.gnome.nautilus.gschema.xml
index 02ca50262..253bc67a1 100644
--- a/data/org.gnome.nautilus.gschema.xml
+++ b/data/org.gnome.nautilus.gschema.xml
@@ -111,7 +111,7 @@
<key type="b" name="install-mime-activation">
<default>true</default>
<summary>Show the package installer for unknown MIME types</summary>
- <description>Whether to show the user a package installer dialog in case an unknown MIME type is opened, in order to search for an application to handle it.</description>
+ <description>Whether to show the user a package installer dialog in case an unknown MIME type is opened, in order to search for an app to handle it.</description>
</key>
<key type="b" name="mouse-use-extra-buttons">
<default>true</default>
@@ -243,7 +243,7 @@
<key type="(ii)" name="initial-size">
<default>(890, 550)</default>
<summary>Initial size of the window</summary>
- <description>A tuple containing the initial width and height of the application window.</description>
+ <description>A tuple containing the initial width and height of the app window.</description>
</key>
<key type="b" name="maximized">
<default>false</default>
diff --git a/src/gtk/nautilusgtkplacessidebar.c b/src/gtk/nautilusgtkplacessidebar.c
index 16c68d79a..d7e6e97d3 100644
--- a/src/gtk/nautilusgtkplacessidebar.c
+++ b/src/gtk/nautilusgtkplacessidebar.c
@@ -4472,7 +4472,7 @@ nautilus_gtk_places_sidebar_class_init (NautilusGtkPlacesSidebarClass *class)
properties[PROP_OPEN_FLAGS] =
g_param_spec_flags ("open-flags",
"Open Flags",
- "Modes in which the calling application can open locations selected in the sidebar",
+ "Modes in which the calling app can open locations selected in the sidebar",
NAUTILUS_TYPE_OPEN_FLAGS,
NAUTILUS_GTK_PLACES_OPEN_NORMAL,
G_PARAM_READWRITE|G_PARAM_STATIC_NAME|G_PARAM_STATIC_NICK|G_PARAM_STATIC_BLURB);
diff --git a/src/gtk/nautilusgtkplacesview.c b/src/gtk/nautilusgtkplacesview.c
index 255d88869..e48ed22e4 100644
--- a/src/gtk/nautilusgtkplacesview.c
+++ b/src/gtk/nautilusgtkplacesview.c
@@ -2335,7 +2335,7 @@ nautilus_gtk_places_view_class_init (NautilusGtkPlacesViewClass *klass)
properties[PROP_OPEN_FLAGS] =
g_param_spec_flags ("open-flags",
"Open Flags",
- "Modes in which the calling application can open locations selected in the sidebar",
+ "Modes in which the calling app can open locations selected in the sidebar",
NAUTILUS_TYPE_OPEN_FLAGS,
NAUTILUS_GTK_PLACES_OPEN_NORMAL,
G_PARAM_READWRITE|G_PARAM_STATIC_NAME|G_PARAM_STATIC_NICK|G_PARAM_STATIC_BLURB);
diff --git a/src/nautilus-application.c b/src/nautilus-application.c
index e6726ee86..675985667 100644
--- a/src/nautilus-application.c
+++ b/src/nautilus-application.c
@@ -972,7 +972,7 @@ nautilus_application_command_line (GApplication *application,
if (g_variant_dict_contains (options, "quit"))
{
- DEBUG ("Killing application, as requested");
+ DEBUG ("Killing app, as requested");
g_action_group_activate_action (G_ACTION_GROUP (application),
"kill", NULL);
goto out;
diff --git a/src/nautilus-dbus-launcher.c b/src/nautilus-dbus-launcher.c
index 491f9675b..e8a43cfa2 100644
--- a/src/nautilus-dbus-launcher.c
+++ b/src/nautilus-dbus-launcher.c
@@ -46,7 +46,7 @@ on_nautilus_dbus_launcher_call_finished (GObject *source_object,
{
g_warning ("Error calling proxy %s", error->message);
message = g_strdup_printf (_("Details: %s"), error->message);
- show_dialog (_("There was an error launching the application."),
+ show_dialog (_("There was an error launching the app."),
message,
window,
GTK_MESSAGE_ERROR);
@@ -91,7 +91,7 @@ nautilus_dbus_launcher_call (NautilusDBusLauncher *self,
}
else if (window != NULL)
{
- show_dialog (_("There was an error launching the application."),
+ show_dialog (_("There was an error launching the app."),
_("Details: The proxy has not been created."),
window,
GTK_MESSAGE_ERROR);
diff --git a/src/nautilus-mime-actions.c b/src/nautilus-mime-actions.c
index b9b8d3078..dc6cce6c6 100644
--- a/src/nautilus-mime-actions.c
+++ b/src/nautilus-mime-actions.c
@@ -1183,12 +1183,12 @@ show_unhandled_type_error (ActivateParametersInstall *parameters)
else
{
content_type_description = g_content_type_get_description (mime_type);
- body = g_strdup_printf (_("There is no application installed for “%s” files"), content_type_description);
+ body = g_strdup_printf (_("There is no app installed for “%s” files"), content_type_description);
}
dialog = adw_message_dialog_new (parameters->parent_window, error_message, body);
adw_message_dialog_add_responses (ADW_MESSAGE_DIALOG (dialog),
- "select-application", _("_Select Application"),
+ "select-application", _("_Select App"),
"ok", _("_OK"),
NULL);
adw_message_dialog_set_default_response (ADW_MESSAGE_DIALOG (dialog), "ok");
@@ -1225,9 +1225,9 @@ search_for_application_dbus_call_notify_cb (GDBusProxy *proxy,
char *message;
message = g_strdup_printf ("%s\n%s",
- _("There was an internal error trying to search for applications:"),
+ _("There was an internal error trying to search for apps:"),
error->message);
- show_dialog (_("Unable to search for application"),
+ show_dialog (_("Unable to search for app"),
message,
parameters_install->parent_window,
GTK_MESSAGE_ERROR);
@@ -1235,7 +1235,7 @@ search_for_application_dbus_call_notify_cb (GDBusProxy *proxy,
}
else
{
- g_warning ("Error while trying to search for applications: %s",
+ g_warning ("Error while trying to search for apps: %s",
error->message);
}
@@ -1339,8 +1339,8 @@ pk_proxy_appeared_cb (GObject *source,
"search-in-software", _("_Search in Software"),
NULL);
adw_message_dialog_format_body (ADW_MESSAGE_DIALOG (dialog),
- _("There is no application installed for “%s” files. "
- "Do you want to search for an application to open this file?"),
+ _("There is no app installed for “%s” files. "
+ "Do you want to search for an app to open this file?"),
content_type_description);
adw_message_dialog_set_default_response (ADW_MESSAGE_DIALOG (dialog), "search-in-software");
diff --git a/src/nautilus-operations-ui-manager.c b/src/nautilus-operations-ui-manager.c
index 2209a2dbd..76e0f62f1 100644
--- a/src/nautilus-operations-ui-manager.c
+++ b/src/nautilus-operations-ui-manager.c
@@ -588,7 +588,7 @@ open_file_in_application (gpointer user_data)
GTK_DIALOG_USE_HEADER_BAR,
mime_type);
heading = _("Password-protected archives are not yet supported. "
- "This list contains applications that can open the archive.");
+ "This list contains apps that can open the archive.");
gtk_app_chooser_dialog_set_heading (GTK_APP_CHOOSER_DIALOG (dialog), heading);
diff --git a/src/nautilus-program-choosing.c b/src/nautilus-program-choosing.c
index ceaee0a63..e05dcd741 100644
--- a/src/nautilus-program-choosing.c
+++ b/src/nautilus-program-choosing.c
@@ -256,7 +256,7 @@ launch_application_from_command_internal (const gchar *full_command,
if (error != NULL)
{
- g_message ("Could not start application: %s", error->message);
+ g_message ("Could not start app: %s", error->message);
}
}
@@ -379,7 +379,7 @@ nautilus_launch_desktop_file (const char *desktop_file_uri,
g_free (desktop_file_path);
if (app_info == NULL)
{
- show_dialog (_("There was an error launching the application."),
+ show_dialog (_("There was an error launching the app."),
NULL,
parent_window,
GTK_MESSAGE_ERROR);
@@ -454,7 +454,7 @@ nautilus_launch_desktop_file (const char *desktop_file_uri,
if (error != NULL)
{
message = g_strconcat (_("Details: "), error->message, NULL);
- show_dialog (_("There was an error launching the application."),
+ show_dialog (_("There was an error launching the app."),
message,
parent_window,
GTK_MESSAGE_ERROR);
diff --git a/src/resources/gtk/help-overlay.ui b/src/resources/gtk/help-overlay.ui
index 30e502d59..ddd065b44 100644
--- a/src/resources/gtk/help-overlay.ui
+++ b/src/resources/gtk/help-overlay.ui
@@ -100,7 +100,7 @@
</child>
<child>
<object class="GtkShortcutsShortcut">
- <property name="title" translatable="yes" context="shortcut window">Open with default application</property>
+ <property name="title" translatable="yes" context="shortcut window">Open with default app</property>
<property name="accelerator">&lt;Primary&gt;O &lt;alt&gt;Down</property>
</object>
</child>
diff --git a/src/resources/ui/nautilus-app-chooser.ui b/src/resources/ui/nautilus-app-chooser.ui
index e30beacdf..370e6a0ae 100644
--- a/src/resources/ui/nautilus-app-chooser.ui
+++ b/src/resources/ui/nautilus-app-chooser.ui
@@ -43,7 +43,7 @@
<property name="wrap">True</property>
<property name="wrap-mode">PANGO_WRAP_WORD_CHAR</property>
<property name="justify">center</property>
- <property name="label" translatable="yes">Choose an application to open the selected files.</property>
+ <property name="label" translatable="yes">Choose an app to open the selected files.</property>
</object>
</child>
<child>
diff --git a/src/nautilus-app-chooser.c b/src/nautilus-app-chooser.c
index e15abc3ae..cca071dfa 100644
--- a/src/nautilus-app-chooser.c
+++ b/src/nautilus-app-chooser.c
@@ -74,7 +74,7 @@ open_cb (NautilusAppChooser *self)
g_autofree gchar *message = NULL;
GtkWidget *message_dialog;
- message = g_strdup_printf (_("Error while setting “%s” as default application: %s"),
+ message = g_strdup_printf (_("Error while setting “%s” as default app: %s"),
g_app_info_get_display_name (info), error->message);
message_dialog = adw_message_dialog_new (GTK_WINDOW (self),
_("Could not set as default"),
@@ -194,8 +194,8 @@ nautilus_app_chooser_constructed (GObject *object)
if (self->file_name != NULL)
{
- /* Translators: %s is the filename. i.e. "Choose an application to open test.jpg" */
- description = g_strdup_printf (_("Choose an application to open <b>%s</b>."), self->file_name);
+ /* Translators: %s is the filename. i.e. "Choose an app to open test.jpg" */
+ description = g_strdup_printf (_("Choose an app to open <b>%s</b>."), self->file_name);
gtk_label_set_markup (GTK_LABEL (self->label_description), description);
}